﻿using System;
using System.Globalization;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;

namespace CSharpWinformsSamples
{
    public class DisplayShapeMap : UserControl
    {
        public DisplayShapeMap()
        {
            InitializeComponent();
        }

        private void DisplayMap_Load(object sender, EventArgs e)
        {
            add_marker_layer3();

            winformsMap1.MapUnit = GeographyUnit.Meter;
            winformsMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);
            winformsMap1.MapClick += new EventHandler<MapClickWinformsMapEventArgs>(winformsMap1_MapClick);


            winformsMap1.CurrentExtent = new RectangleShape(-139.2, 92.4, 120.9, -93.2);
            ManagedProj4Projection proj4 = new ManagedProj4Projection();
            proj4.InternalProjectionParametersString = ManagedProj4Projection.GetDecimalDegreesParametersString();
            proj4.ExternalProjectionParametersString = ManagedProj4Projection.GetGoogleMapParametersString();

            proj4.Open();

            winformsMap1.CurrentExtent = proj4.ConvertToExternalProjection(winformsMap1.CurrentExtent) as RectangleShape;

            winformsMap1.Refresh();
        }

        public void add_marker_layer3()
        {
            try
            {
                LayerOverlay pointOverlay = new LayerOverlay();
                InMemoryFeatureLayer pointLayer2 = new InMemoryFeatureLayer();
                pointLayer2.Open();
                pointLayer2.ZoomLevelSet.ZoomLevel01.DefaultPointStyle.PointType = PointType.Bitmap;
                pointLayer2.ZoomLevelSet.ZoomLevel01.DefaultPointStyle.SymbolSize = 5;
                pointLayer2.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                pointLayer2.Close();
                pointOverlay.Layers.Add("PointLayer", pointLayer2);
                winformsMap1.Overlays.Add("pointOverlay3", pointOverlay);
                Proj4Projection prj4 = new Proj4Projection();
                prj4.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);
                prj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
                prj4.Open();
                pointLayer2.FeatureSource.Projection = prj4;
                prj4.Close();
                winformsMap1.Refresh();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error");
            }

        }

        public void add_marker2(double lat, double Long, string name)
        {
            try
            {
                double latitude = Convert.ToDouble(lat, CultureInfo.InvariantCulture);
                double longitude = Convert.ToDouble(Long, CultureInfo.InvariantCulture);
                Feature feature = new Feature(longitude, latitude, name);
                InMemoryFeatureLayer pointLayer = (InMemoryFeatureLayer)winformsMap1.FindFeatureLayer("PointLayer");
                pointLayer.Open();
                pointLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle.Image = new GeoImage(@"C:\Users\LABPC3\Desktop\AQUA_red.png");
                pointLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;


                if (!pointLayer.InternalFeatures.Contains(name))
                {
                    pointLayer.InternalFeatures.Add(name, feature);
                }
                pointLayer.Close();

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error");
            }
        }

        void winformsMap1_MapClick(object sender, MapClickWinformsMapEventArgs e)
        {
            PointShape originalShape = ExtentHelper.ToWorldCoordinate(winformsMap1.CurrentExtent, new ScreenPointF(e.ScreenX, e.ScreenY), winformsMap1.Width, winformsMap1.Height);
            ManagedProj4Projection projection = new ManagedProj4Projection();
            projection.InternalProjectionParametersString = ManagedProj4Projection.GetEpsgParametersString(4326);
            projection.ExternalProjectionParametersString = ManagedProj4Projection.GetGoogleMapParametersString();
            projection.Open();
            PointShape decimalDegreePoint = (PointShape)projection.ConvertToInternalProjection(originalShape);
            projection.Close();

            add_marker2(decimalDegreePoint.Y, decimalDegreePoint.X, Guid.NewGuid().ToString());

            winformsMap1.Refresh();
        }

        private WinformsMap winformsMap1;

        #region Component Designer generated code

        private System.ComponentModel.IContainer components = null;

        /// <summary> 
        /// Clean up any resources being used.
        /// </summary>
        /// <param name="disposing">true if managed resources should be disposed; otherwise, false.</param>
        protected override void Dispose(bool disposing)
        {
            if (disposing && (components != null))
            {
                components.Dispose();
            }
            base.Dispose(disposing);
        }

        /// <summary> 
        /// Required method for Designer support - do not modify 
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            ThinkGeo.MapSuite.DesktopEdition.EditInteractiveOverlay editInteractiveOverlay1 = new ThinkGeo.MapSuite.DesktopEdition.EditInteractiveOverlay();
            ThinkGeo.MapSuite.DesktopEdition.ExtentInteractiveOverlay extentInteractiveOverlay1 = new ThinkGeo.MapSuite.DesktopEdition.ExtentInteractiveOverlay();
            ThinkGeo.MapSuite.DesktopEdition.TrackInteractiveOverlay trackInteractiveOverlay1 = new ThinkGeo.MapSuite.DesktopEdition.TrackInteractiveOverlay();
            this.winformsMap1 = new ThinkGeo.MapSuite.DesktopEdition.WinformsMap();
            this.SuspendLayout();
            // 
            // winformsMap1
            // 
            this.winformsMap1.BackColor = System.Drawing.Color.Gray;
            this.winformsMap1.Dock = System.Windows.Forms.DockStyle.Fill;
            editInteractiveOverlay1.IsVisible = true;
            editInteractiveOverlay1.Name = null;
            this.winformsMap1.EditOverlay = editInteractiveOverlay1;
            extentInteractiveOverlay1.IsVisible = true;
            extentInteractiveOverlay1.Name = null;
            this.winformsMap1.ExtentOverlay = extentInteractiveOverlay1;
            this.winformsMap1.Location = new System.Drawing.Point(0, 0);
            this.winformsMap1.MapUnit = ThinkGeo.MapSuite.Core.GeographyUnit.DecimalDegree;
            this.winformsMap1.MaximumScale = 80000000000000;
            this.winformsMap1.MinimumScale = 200;
            this.winformsMap1.Name = "winformsMap1";
            this.winformsMap1.MapResizeMode = ThinkGeo.MapSuite.Core.MapResizeMode.PreserveScale;
            this.winformsMap1.Size = new System.Drawing.Size(740, 528);
            this.winformsMap1.TabIndex = 0;
            this.winformsMap1.Text = "winformsMap1";
            trackInteractiveOverlay1.IsVisible = true;
            trackInteractiveOverlay1.Name = null;
            trackInteractiveOverlay1.TrackMode = ThinkGeo.MapSuite.DesktopEdition.TrackMode.None;
            this.winformsMap1.TrackOverlay = trackInteractiveOverlay1;
            this.winformsMap1.ZoomLevelSnapping = ThinkGeo.MapSuite.DesktopEdition.ZoomLevelSnappingMode.Default;
            this.winformsMap1.ExtentOverlay.ZoomPercentage = 40;
            // 
            // DisplayShapeMap
            // 
            this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
            this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
            this.Controls.Add(this.winformsMap1);
            this.Name = "DisplayShapeMap";
            this.Size = new System.Drawing.Size(740, 528);
            this.Load += new System.EventHandler(this.DisplayMap_Load);
            this.ResumeLayout(false);

        }

        #endregion
    }
}
